package com.landray.kmss.sys.attachment.util;

import com.landray.kmss.sys.config.util.LicenseUtil;
import com.landray.kmss.sys.filestore.model.SysFileViewerParam;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.util.ArrayUtil;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import org.apache.poi.hssf.usermodel.HSSFPalette;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.ss.usermodel.FillPatternType;
import org.apache.poi.ss.usermodel.BorderStyle;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Row;
import java.io.InputStream;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import com.landray.kmss.sys.transport.service.spring.ImportUtil;
import java.io.Closeable;
import org.apache.commons.io.IOUtils;
import org.apache.poi.ss.usermodel.WorkbookFactory;
import com.landray.kmss.web.upload.FormFile;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import com.landray.kmss.common.dao.HQLParameter;
import java.util.Collection;
import com.landray.kmss.common.dao.HQLWrapper;
import com.landray.kmss.util.HQLUtil;
import java.util.Arrays;
import org.apache.commons.lang.StringUtils;
import com.landray.kmss.util.UserUtil;
import java.util.ArrayList;
import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import com.landray.kmss.common.convertor.FormConvertor_Common;
import com.landray.kmss.common.convertor.IFormToModelConvertor;
import java.util.HashMap;
import com.landray.kmss.common.convertor.ConvertorContext;
import com.landray.kmss.common.forms.IExtendForm;
import java.util.List;
import net.sf.json.JSONObject;
import net.sf.json.JSONArray;
import com.landray.kmss.constant.SysAuthConstant;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.sys.config.dict.SysDictModel;
import java.util.Iterator;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.common.service.IBaseService;
import com.landray.kmss.sys.config.dict.SysDictModelProperty;
import org.apache.commons.beanutils.BeanUtils;
import com.landray.kmss.sys.config.dict.SysDictSimpleProperty;
import com.landray.kmss.sys.config.dict.SysDictCommonProperty;
import org.apache.commons.beanutils.PropertyUtils;
import com.landray.kmss.util.StringUtil;
import java.util.Map;
import com.landray.kmss.sys.config.dict.SysDataDict;
import com.landray.kmss.util.ModelUtil;
import com.landray.kmss.common.actions.RequestContext;
import com.landray.kmss.common.model.IBaseModel;

public class SysAttachmentUtil
{
    public static void initModelFromRequest(final IBaseModel model, final RequestContext request) throws Exception {
        if (request.getParameterMap() == null) {
            return;
        }
        final String modelName = ModelUtil.getModelClassName((Object)model);
        final SysDataDict dataDict = SysDataDict.getInstance();
        final Map<String, SysDictCommonProperty> propMap = dataDict.getModel(modelName).getPropertyMap();
        for (final Map.Entry<String, String[]> entry : request.getParameterMap().entrySet()) {
            final String key = entry.getKey();
            if (key.length() >= 3) {
                if (!key.startsWith("i.")) {
                    continue;
                }
                final String[] values = entry.getValue();
                if (values == null || values.length == 0) {
                    continue;
                }
                if (StringUtil.isNull(values[0])) {
                    continue;
                }
                final String propName = key.substring(2);
                if (!PropertyUtils.isWriteable((Object)model, propName)) {
                    continue;
                }
                final SysDictCommonProperty prop = propMap.get(propName);
                if (prop == null || prop.isReadOnly()) {
                    continue;
                }
                if (!prop.isCanDisplay()) {
                    continue;
                }
                if (prop instanceof SysDictSimpleProperty) {
                    BeanUtils.copyProperty((Object)model, propName, (Object)values[0]);
                }
                else {
                    if (!(prop instanceof SysDictModelProperty)) {
                        continue;
                    }
                    final SysDictModel dictModel = dataDict.getModel(prop.getType());
                    if (dictModel == null) {
                        continue;
                    }
                    IBaseService service = null;
                    final String beanName = dictModel.getServiceBean();
                    if (StringUtil.isNotNull(beanName)) {
                        service = (IBaseService)SpringBeanUtil.getBean(beanName);
                    }
                    if (service == null) {
                        continue;
                    }
                    final IBaseModel value = service.findByPrimaryKey(values[0]);
                    BeanUtils.copyProperty((Object)model, propName, (Object)value);
                }
            }
        }
    }
    
    public static String buildCriteria(final String serviceBean, final String selectBlock, final String whereBlock, final String orderBy) throws Exception {
        final IBaseService service = (IBaseService)SpringBeanUtil.getBean(serviceBean);
        final HQLInfo hqlInfo = new HQLInfo();
        hqlInfo.setSelectBlock(selectBlock);
        hqlInfo.setWhereBlock(whereBlock);
        hqlInfo.setOrderBy(orderBy);
        hqlInfo.setCheckParam((Enum)SysAuthConstant.CheckType.AuthCheck, (Object)SysAuthConstant.AuthCheck.SYS_EDITOR);
        final List rtnList = service.findValue(hqlInfo);
        final JSONArray result = new JSONArray();
        for (final Object rtnVal : rtnList) {
            if (rtnVal == null) {
                continue;
            }
            String optValue = null;
            String optText = null;
            if (rtnVal instanceof Object[]) {
                final Object[] rtnVals = (Object[])rtnVal;
                if (rtnVals.length == 0) {
                    continue;
                }
                if (rtnVals[0] == null) {
                    continue;
                }
                optValue = rtnVals[0].toString();
                if (rtnVals.length > 1 && rtnVals[1] != null) {
                    optText = rtnVals[1].toString();
                }
                else {
                    optText = optValue;
                }
            }
            else {
                optValue = (optText = rtnVal.toString());
            }
            final JSONObject json = new JSONObject();
            json.put((Object)"value", (Object)optValue);
            json.put((Object)"text", (Object)optText);
            result.add((Object)json);
        }
        return result.toString();
    }
    
    public static final void convert(final IBaseService baseService, final IExtendForm $baseForm, final IBaseModel $baseModel, final String[] props, final RequestContext requestContext) throws Exception {
        if (props == null || props.length < 1) {
            return;
        }
        final ConvertorContext context = new ConvertorContext();
        context.setBaseService(baseService);
        context.setSObject((Object)$baseForm);
        context.setTObject((Object)$baseModel);
        context.setObjMap((Map)new HashMap());
        context.setRequestContext(requestContext);
        final Map propertyMap = $baseForm.getToModelPropertyMap().getPropertyMap();
        for (final String prop : props) {
            if (prop != null) {
                if (prop.trim().length() >= 1) {
                    IFormToModelConvertor convertor = propertyMap.get(prop);
                    if (convertor == null) {
                        convertor = (IFormToModelConvertor)new FormConvertor_Common(prop);
                    }
                    context.setSPropertyName(prop);
                    convertor.excute(context);
                }
            }
        }
    }
    
    public static final Date getDateByValue(final String value) {
        if (value != null && !"#now".equals(value)) {
            final int num = Integer.valueOf(value.split(";")[1]);
            if (value.startsWith("#dayslater")) {
                final Calendar calendar = Calendar.getInstance();
                calendar.setTime(new Date());
                calendar.add(5, num);
                return calendar.getTime();
            }
            if (value.startsWith("#hourslater")) {
                final Calendar calendar = Calendar.getInstance();
                calendar.setTime(new Date());
                calendar.add(10, num);
                return calendar.getTime();
            }
            if (value.startsWith("#minuteslater")) {
                final Calendar calendar = Calendar.getInstance();
                calendar.setTime(new Date());
                calendar.add(12, num);
                return calendar.getTime();
            }
        }
        return new Date();
    }
    
    public static final Date getDateByValue(final String value, final String dateType) {
        final Date date = getDateByValue(value);
        if ("time".equals(dateType)) {
            final Calendar calendar = Calendar.getInstance();
            calendar.setTime(date);
            calendar.set(1, 1970);
            calendar.set(2, 0);
            calendar.set(5, 1);
            calendar.set(13, 0);
            calendar.set(14, 0);
            return calendar.getTime();
        }
        if ("date".equals(dateType)) {
            final Calendar calendar = Calendar.getInstance();
            calendar.setTime(date);
            calendar.set(11, 0);
            calendar.set(12, 0);
            calendar.set(13, 0);
            calendar.set(14, 0);
            return calendar.getTime();
        }
        return date;
    }
    
    public static final String getDateStrByValue(final String value, final String dateType) {
        final Date date = getDateByValue(value, dateType);
        final SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return sdf.format(date);
    }
    
    public static void buildHqlInfoDateType(final HQLInfo hqlInfo, final List<Map<String, String>> paramList, final Class<?> clazz) {
        if (paramList != null) {
            final String modelName = clazz.getName();
            final String shortName = ModelUtil.getModelTableName((Object)modelName);
            int i = 0;
            for (final Map<String, String> paramMap : paramList) {
                final String keyInfo = paramMap.get("key");
                final String[] names = keyInfo.split("\\.");
                final String opt = names[0];
                final String fieldName = names[1];
                final String valueInfo = paramMap.get("value");
                final String dateType = paramMap.get("dateType");
                if ("isnull".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "is null"));
                }
                else if ("nnull".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "is not null"));
                }
                else if ("eq".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "=:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                else if ("ne".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "!=:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                else if ("lt".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "<:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                else if ("lte".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + "<=:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                else if ("gt".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + ">:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                else if ("gte".equals(opt)) {
                    hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", String.valueOf(shortName) + "." + fieldName + ">=:" + fieldName + String.valueOf(i)));
                    hqlInfo.setParameter(String.valueOf(fieldName) + String.valueOf(i), (Object)getDateByValue(valueInfo, dateType));
                }
                ++i;
            }
        }
    }
    
    public static void buildHqlInfoDate(final HQLInfo hqlInfo, final HttpServletRequest request, final Class<?> clazz) {
        final String[] dateInfo = request.getParameterValues("dateInfo");
        final List<Map<String, String>> paramList = new ArrayList<Map<String, String>>();
        if (dateInfo != null) {
            String[] array;
            for (int length = (array = dateInfo).length, i = 0; i < length; ++i) {
                final String info = array[i];
                final String[] infos = info.split(";");
                final Map map = new HashMap();
                if (3 == infos.length) {
                    map.put("key", infos[0]);
                    map.put("value", "#" + infos[1]);
                    map.put("dateType", infos[2]);
                }
                else {
                    map.put("key", infos[0]);
                    map.put("value", "#" + infos[1] + ";" + infos[2]);
                    map.put("dateType", infos[3]);
                }
                paramList.add(map);
            }
            buildHqlInfoDateType(hqlInfo, paramList, clazz);
        }
    }
    
    public static void buildHqlInfoModel(final HQLInfo hqlInfo, final HttpServletRequest request) throws Exception {
        final String[] modelInfo = request.getParameterValues("modelInfo");
        if (modelInfo != null) {
            String[] array;
            for (int length = (array = modelInfo).length, i = 0; i < length; ++i) {
                final String info = array[i];
                final String[] infos = info.split(":");
                if (infos != null) {
                    final String[] key = infos[0].split(".");
                    final String opt = key[0];
                    final String property = key[1];
                    final String values = infos[1];
                    buildHqlInfoModelType(property, property, hqlInfo, opt, values);
                }
            }
        }
    }
    
    public static void buildHqlInfoModelType(final String shortName, final String key, final HQLInfo hqlInfo, final String opt, String value) throws Exception {
        String optKey = "";
        if ("isnull".equals(opt)) {
            optKey = "is null";
        }
        else if ("nnull".equals(opt)) {
            optKey = "is not null";
        }
        else if ("eq".equals(opt)) {
            optKey = "=";
        }
        else if ("ne".equals(opt)) {
            optKey = "!=";
        }
        else if ("in".equals(opt)) {
            optKey = "in";
        }
        else if ("nin".equals(opt)) {
            optKey = "not in";
        }
        if ("currentPerson".equals(value)) {
            if (UserUtil.getKMSSUser().getUserId() != null) {
                value = UserUtil.getKMSSUser().getUserId();
            }
            else {
                value = "";
            }
        }
        if ("currentPost".equals(value)) {
            if (UserUtil.getKMSSUser().getPostIds() != null) {
                value = StringUtils.join((Object[])UserUtil.getKMSSUser().getPostIds(), ";");
            }
            else {
                value = "";
            }
        }
        if ("currentDept".equals(value)) {
            if (UserUtil.getKMSSUser().getDeptId() != null) {
                value = UserUtil.getKMSSUser().getDeptId();
            }
            else {
                value = "";
            }
        }
        if ("currentOrg".equals(value)) {
            if (UserUtil.getUser().getFdParentOrg() != null) {
                value = UserUtil.getUser().getFdParentOrg().getFdId();
            }
            else {
                value = "";
            }
        }
        String whereBlock = hqlInfo.getWhereBlock();
        final String propKey = shortName.contains(".fdId") ? shortName : (String.valueOf(shortName) + ".fdId");
        if (StringUtil.isNotNull(whereBlock)) {
            whereBlock = String.valueOf(whereBlock) + " and ";
        }
        if ("is null".equals(optKey) || "is not null".equals(optKey)) {
            whereBlock = String.valueOf(whereBlock) + propKey + " " + optKey;
        }
        else if ("in".equals(optKey) || "not in".equals(optKey)) {
            if (value.contains(";")) {
                List valueList = null;
                HQLWrapper hqlW = null;
                valueList = Arrays.asList(value.split(";"));
                if ("in".equals(optKey)) {
                    hqlW = HQLUtil.buildPreparedLogicIN(propKey, (String)null, valueList);
                }
                else {
                    hqlW = _buildPreparedLogicNotIN(propKey, null, valueList);
                }
                whereBlock = String.valueOf(whereBlock) + hqlW.getHql();
                hqlInfo.setParameter(hqlW.getParameterList());
            }
            else {
                optKey = ("in".equals(optKey) ? "=" : "!=");
                whereBlock = String.valueOf(whereBlock) + propKey + " " + optKey + " :" + key;
                hqlInfo.setParameter(key, (Object)value);
            }
        }
        else {
            whereBlock = String.valueOf(whereBlock) + propKey + " " + optKey + " :" + key;
            hqlInfo.setParameter(key, (Object)value);
        }
        hqlInfo.setWhereBlock(whereBlock);
    }
    
    private static HQLWrapper _buildPreparedLogicNotIN(final String item, final String alias, final List<?> valueList) {
        String param = alias;
        if (StringUtil.isNull(param)) {
            param = Integer.toHexString(System.identityHashCode(item));
        }
        final List<?> valueCopy = new ArrayList<Object>(valueList);
        final HQLWrapper hqlWrapper = new HQLWrapper();
        final int n = (valueCopy.size() - 1) / 1000;
        final StringBuffer whereBlockTmp = new StringBuffer();
        for (int k = 0; k <= n; ++k) {
            final int size = (k == n) ? valueCopy.size() : ((k + 1) * 1000);
            if (k > 0) {
                whereBlockTmp.append(" and ");
            }
            final String para = "kmss_in_" + param + "_" + k;
            whereBlockTmp.append(String.valueOf(item) + " not in (:" + para + ")");
            final List<?> tmpList = valueCopy.subList(k * 1000, size);
            final HQLParameter hqlParameter = new HQLParameter(para, (Object)tmpList);
            hqlWrapper.setParameter(hqlParameter);
        }
        if (n > 0) {
            hqlWrapper.setHql("(" + whereBlockTmp.toString() + ")");
        }
        else {
            hqlWrapper.setHql(whereBlockTmp.toString());
        }
        return hqlWrapper;
    }
    
    public static String encodeFileName(final HttpServletRequest request, String oldFileName) throws UnsupportedEncodingException {
        final String userAgent = request.getHeader("User-Agent").toUpperCase();
        if (userAgent.indexOf("MSIE") > -1 || userAgent.indexOf("TRIDENT") > -1 || userAgent.indexOf("EDGE") > -1) {
            oldFileName = URLEncoder.encode(oldFileName, "UTF-8");
            oldFileName = oldFileName.replace("+", "%20");
        }
        else {
            oldFileName = new String(oldFileName.getBytes("UTF-8"), "ISO8859-1");
        }
        return oldFileName;
    }
    
    public static org.json.simple.JSONArray importData(final FormFile file, final org.json.simple.JSONArray jsArray) throws Exception {
        Workbook wb = null;
        Sheet sheet = null;
        InputStream input = null;
        try {
            input = file.getInputStream();
            wb = WorkbookFactory.create(input);
            sheet = wb.getSheetAt(0);
        }
        catch (final Exception ex) {
            throw new RuntimeException("上传文件格式错误！系统预期的文件为Excel文件格式");
        }
        finally {
            IOUtils.closeQuietly((Closeable)wb);
            IOUtils.closeQuietly(input);
        }
        IOUtils.closeQuietly((Closeable)wb);
        IOUtils.closeQuietly(input);
        final int rowNum = sheet.getLastRowNum();
        if (rowNum < 1) {
            return null;
        }
        String ths = "";
        final Row rowFirst = sheet.getRow(0);
        final int cellNumFirst = rowFirst.getLastCellNum();
        for (int k = 0; k < cellNumFirst; ++k) {
            final String valueFirst = ImportUtil.getCellValue(rowFirst.getCell(k));
            ths = String.valueOf(ths) + "," + valueFirst;
        }
        JSONObject job = new JSONObject();
        job.element("ths", (Object)ths.substring(1, ths.length()));
        jsArray.add((Object)job);
        for (int i = 1; i <= sheet.getLastRowNum(); ++i) {
            final Row row = sheet.getRow(i);
            if (row != null) {
                String values = "";
                for (int j = 0; j < cellNumFirst; ++j) {
                    String value = "";
                    try {
                        value = ImportUtil.getCellValue(row.getCell(j));
                        if (value != null) {
                            values = String.valueOf(values) + ";" + value;
                        }
                        else {
                            values = String.valueOf(values) + ";";
                        }
                    }
                    catch (final Exception e) {
                        e.printStackTrace();
                    }
                }
                job = new JSONObject();
                job.element("value", (Object)values.substring(1, values.length()));
                jsArray.add((Object)job);
            }
        }
        return jsArray;
    }
    
    public static HSSFWorkbook buildWorkBook(final String[] Headers) throws Exception {
        final HSSFWorkbook wb = new HSSFWorkbook();
        final HSSFSheet sheet1 = wb.createSheet("列表数据导出");
        buildTemplate(wb, sheet1, Headers);
        return wb;
    }
    
    public static HSSFWorkbook exportWorkBook(final String[] Headers, final List list) throws Exception {
        HSSFRow row = null;
        int rowCount = 1;
        final HSSFWorkbook workbook = buildWorkBook(Headers);
        final HSSFSheet sheet1 = workbook.getSheetAt(0);
        if (list != null) {
            for (final Object data : list) {
                row = sheet1.createRow(rowCount++);
                final List dataLast = (List)data;
                final List value = dataLast.get(1);
                buileOneNcCustomer(row, value);
            }
        }
        return workbook;
    }
    
    private static HSSFCellStyle getCellStyle(final HSSFWorkbook wb, final boolean isCenter) {
        final HSSFCellStyle style = wb.createCellStyle();
        if (isCenter) {
            style.setAlignment(HorizontalAlignment.CENTER);
            style.setVerticalAlignment(VerticalAlignment.CENTER);
        }
        style.setWrapText(true);
        style.setBorderBottom(BorderStyle.valueOf((short)1));
        style.setBorderLeft(BorderStyle.valueOf((short)1));
        style.setBorderTop(BorderStyle.valueOf((short)1));
        style.setBorderRight(BorderStyle.valueOf((short)1));
        return style;
    }
    
    private static void setBackgroundColor(final HSSFCellStyle style, final boolean isMain) {
        style.setFillPattern(FillPatternType.SOLID_FOREGROUND);
        if (isMain) {
            style.setFillForegroundColor((short)44);
        }
        else {
            style.setFillForegroundColor((short)22);
        }
    }
    
    private static HSSFFont getTitleFont(final HSSFWorkbook wb, final boolean isRed) {
        final HSSFFont font = wb.createFont();
        font.setBold(true);
        if (isRed) {
            font.setColor((short)10);
        }
        return font;
    }
    
    private static void buildTemplate(final HSSFWorkbook wb, final HSSFSheet sheet, final String[] Headers) {
        HSSFRow row = null;
        HSSFCell cell = null;
        HSSFCellStyle style = null;
        sheet.setDefaultColumnWidth(20);
        row = sheet.createRow(0);
        int cellIndex = 0;
        for (int i = 0; i < Headers.length; ++i) {
            cell = row.createCell(cellIndex++);
            style = getCellStyle(wb, true);
            setBackgroundColor(style, true);
            style.setFont(getTitleFont(wb, false));
            cell.setCellStyle(style);
            cell.setCellValue(Headers[i]);
        }
        final HSSFPalette palette = wb.getCustomPalette();
        palette.setColorAtIndex((short)44, (byte)91, (byte)(-101), (byte)(-43));
        palette.setColorAtIndex((short)22, (byte)(-39), (byte)(-39), (byte)(-39));
    }
    
    private static void buileOneNcCustomer(final HSSFRow row, final List values) throws Exception {
        HSSFCell cell = null;
        int cellIndex = 0;
        for (final Object value : values) {
            final List valueLast = (List)value;
            cell = row.createCell(cellIndex++);
            cell.setCellValue(valueLast.get(1).toString());
        }
    }
    
    public static Boolean isInCludeChrome(final HttpServletRequest request) {
        final int index = request.getHeader("User-Agent").toUpperCase().indexOf("CHROME/");
        if (index > 0) {
            final String chromeV = request.getHeader("User-Agent").toUpperCase();
            final String v3 = chromeV.substring(index + 7, index + 10);
            int v4;
            if (v3.contains(".")) {
                v4 = Integer.parseInt(v3.substring(0, 2));
            }
            else {
                v4 = Integer.parseInt(v3);
            }
            if (v4 > 106) {
                return true;
            }
        }
        return false;
    }
    
    public static Boolean isConvertByView(final HttpServletRequest request, final String fdModelName, final String fdKey) {
        try {
            final String _modelId = request.getParameter("fdId");
            final ISysAttMainCoreInnerService sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
            final List sysAttMains = sysAttMainService.findByModelKey(fdModelName, _modelId, fdKey);
            if (!ArrayUtil.isEmpty(sysAttMains)) {
                final SysAttMain SysAttMain = sysAttMains.get(0);
                SysAttViewerUtil.addQueue(SysAttMain);
                final List<SysFileViewerParam> convertedParams = SysAttViewerUtil.getConvertedParams(SysAttMain);
                if (convertedParams != null && convertedParams.size() > 0) {
                    return true;
                }
            }
        }
        catch (final Exception ex) {
            return false;
        }
        return false;
    }
    
    public static String getLincenseId() {
        String _lincense = "";
        final String _linId = LicenseUtil.get("license-customer-id");
        final String _linExt = LicenseUtil.get("lincense-extend-env-name");
        if (StringUtil.isNotNull(_linExt)) {
            _lincense = String.valueOf(_linId) + "-" + _linExt;
        }
        else {
            _lincense = _linId;
        }
        return _lincense;
    }
}
